<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>EditHatch</name>
    <message>
        <location filename="../EditHatch.js" line="+61"/>
        <source>Choose hatch</source>
        <translation>Vybrať šrafovanie/výplň</translation>
    </message>
    <message>
        <location filename="../EditHatchInit.js" line="+2"/>
        <source>Edit &amp;Hatch</source>
        <translation>Upraviť &amp;Šrafovanie/Výplň</translation>
    </message>
</context>
<context>
    <name>EditText</name>
    <message>
        <source>Choose text</source>
        <translation type="vanished">Vybrať text</translation>
    </message>
    <message>
        <source>Edit Te&amp;xt</source>
        <translation type="vanished">Upraviť te&amp;xt</translation>
    </message>
    <message>
        <source>Edit text</source>
        <translation type="vanished">Upraviť text</translation>
    </message>
</context>
</TS>
